@@ -1,3 +1,6 @@
+# SPDX-FileCopyrightText: 2021 Melissa LeBlanc-Williams for Adafruit Industries
+#
+# SPDX-License-Identifier: MIT
 """Allwinner H5 pin names"""
 from adafruit_blinka.microcontroller.generic_linux.libgpiod_pin import Pin
 
@@ -42,6 +45,7 @@ SPI0_CS = PC3
 PC4 = Pin((1, 68))
 PC7 = Pin((1, 71))
 
+PD11 = Pin((1, 107))
 PD14 = Pin((1, 110))
 
 PG6 = Pin((1, 198))
